summaryrefslogtreecommitdiff
path: root/firmware/2lib/include/2nvstorage.h
diff options
context:
space:
mode:
Diffstat (limited to 'firmware/2lib/include/2nvstorage.h')
-rw-r--r--firmware/2lib/include/2nvstorage.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/firmware/2lib/include/2nvstorage.h b/firmware/2lib/include/2nvstorage.h
index 32a9b0a0..9de8056e 100644
--- a/firmware/2lib/include/2nvstorage.h
+++ b/firmware/2lib/include/2nvstorage.h
@@ -46,8 +46,8 @@ enum vb2_nv_param {
VB2_NV_LOCALIZATION_INDEX,
/* Field reserved for kernel/user-mode use; 16-bit value. */
VB2_NV_KERNEL_FIELD,
- /* Allow booting from USB in developer mode. 0=no, 1=yes. */
- VB2_NV_DEV_BOOT_USB,
+ /* Allow booting from external disk in developer mode. 0=no, 1=yes. */
+ VB2_NV_DEV_BOOT_EXTERNAL,
/* Allow booting of legacy OSes in developer mode. 0=no, 1=yes. */
VB2_NV_DEV_BOOT_LEGACY,
/* Only boot Google-signed images in developer mode. 0=no, 1=yes. */